import flash.events.Event;

import mx.collections.ArrayCollection;
import mx.controls.Alert;
import mx.events.ResizeEvent;
import mx.rpc.events.FaultEvent;
import mx.rpc.events.ResultEvent;

import webdb.addressbook.Card;
import mx.rpc.remoting.mxml.RemoteObject;
import mx.utils.ObjectUtil;
import mx.formatters.DateFormatter;

private var ro:RemoteObject = new RemoteObject();

/* 現在選択されているカード */
[Bindable]
private var selectedCard:Card;

private function init():void {
	// RemoteObjectの設定
	ro.destination = "addressBookService";
	ro.showBusyCursor = true;
	ro.addEventListener(FaultEvent.FAULT, onFault);
	ro.getCards.addEventListener(ResultEvent.RESULT, onGetCards);
	ro.saveCard.addEventListener(ResultEvent.RESULT, onSave);
	ro.deleteCard.addEventListener(ResultEvent.RESULT, onDelete);
	getCards();
}

private function getCards():void {
	ro.getCards();
}

private function onGetCards(re:ResultEvent):void {
	trace(ObjectUtil.toString(re.result)); //re.resultがCardオブジェクトの配列になっていることを確認。
	var cards:Array = re.result as Array;
	var cardCollection:ArrayCollection = new ArrayCollection(cards);
	listDG.dataProvider = cardCollection;
}

/**
 * 保存ボタンクリック時に呼ばれるメソッド
 */
private function saveCard():void {
	var card:Card = selectedCard ? selectedCard : new Card();
	card.lastName = lastNameTxt.text;
	card.firstName = firstNameTxt.text;
	card.lastNameYomi = lastNameYomiTxt.text;
	card.firstNameYomi = firstNameYomiTxt.text;
	card.company = companyTxt.text;
	card.tel = telTxt.text;
	card.email = emailTxt.text;
	card.zip = zipTxt.text;
	card.address = addressTA.text;
	card.url = urlTxt.text;
	card.birthday = birthdayDF.selectedDate;
	card.portrait = portrait.getByteArrayOfPortrait();
	ro.saveCard(card);
}

private function onSave(re:ResultEvent):void {
	getCards();
	newCard();
}

/**
 * 削除ボタンクリック時に呼ばれるメソッド
 */
private function deleteCard():void {
	ro.deleteCard(selectedCard.id);
}

private function onDelete(re:ResultEvent):void {
	var list:ArrayCollection = ArrayCollection(listDG.dataProvider);
	var index:int = list.getItemIndex(selectedCard);
	if (index != -1) {
		list.removeItemAt(index);
	}
	newCard();
}

/**
 * 新規データボタンをクリックした時に呼ばれるメソッド
 */
private function newCard():void {
	selectedCard = null;
	portrait.doErase(true);
	lastNameTxt.text = "";
	firstNameTxt.text = "";
	lastNameYomiTxt.text = "";
	firstNameYomiTxt.text = "";
	companyTxt.text = "";
	telTxt.text = "";
	emailTxt.text = "";
	zipTxt.text = "";
	addressTA.text = "";
	urlTxt.text = "";
	birthdayDF.text = "";
	lastNameTxt.setFocus();
}

/**
 * エラー時に呼ばれるメソッド。
 * Alertダイアログを表示。
 */
private function onFault(fe:FaultEvent):void {
	trace(fe.fault.faultDetail);
	Alert.show(fe.fault.faultString);
}

private function showCard(card:Card):void {
	if (!card) {
		return;
	}
	selectedCard = card;
	lastNameTxt.text = card.lastName;
	firstNameTxt.text = card.firstName;
	lastNameYomiTxt.text = card.lastNameYomi;
	firstNameYomiTxt.text = card.firstNameYomi;
	companyTxt.text = card.company;
	telTxt.text = card.tel;
	emailTxt.text = card.email;
	zipTxt.text = card.zip;
	addressTA.text = card.address;
	urlTxt.text = card.url;
	if (card.birthday != null) {
		var formatter:DateFormatter = new DateFormatter();
		formatter.formatString = "YYYY/MM/DD";
		birthdayDF.text = formatter.format(card.birthday);
	} else {
		birthdayDF.text = "";
	}
	if (card.portraitUrl != null) {
		portrait.showImageOnCanvas(card.portraitUrl);
	} else {
		portrait.doErase(true);
	}
}